# Copyright (C) 2006 Kumar McMillan
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.

"""Tools for controlling test environments.

This package came to life while developing real test suites for applications and libraries, 
so nothing has been added here that wasn't necessary for some task or another.  
`Python`_ is of course the ultimate testing tool.

In my own experience with testing, it pays to get as close to the real world as possible.
I try to use stub or mock objects only as a last resort, for optimization, etc.  Thus, the crux of this package is the `fixtures` module -- 
it provides the means to load mock data into a real database (or any storage medium).  

Patches are welcome, preferably with tests ;)  The current project is being trac'ed at http://testtools.python-hosting.com/

See docs on each individual module for examples and usage.

.. _Python: http://python.org/

"""

__all__ = [ 'fixtures', 'io', 'stubs', 'storage', 'config', 
            'exceptions', 'bgtests', '__version__', ]
__repos_url__ = '$HeadURL: https://svn.testtools.python-hosting.com/tags/0.7.6.1/testtools/__init__.py $'

import sre

_ver_pattern = sre.compile('(?:branches|tags)/([^/]+)/')

def release_version(repos_url = __repos_url__):
    '''get a release version string based on the 
    branch/tag in the repos url for this file
    
    '''
    m = _ver_pattern.search(repos_url)
    if m:
        return m.group(1)
    else:
        return 'dev'

__version__ = release_version()
