
from unittest import TestCase
from testtools.fixtures import Fixture
from testtools.fixtures.registry import *

class MockFixture(Fixture):
    def __init__(self, **kw):
        self.__dict__ = kw
        class meta: pass
        self.meta = meta()
        self.meta.req = Fixture.RequiredPool()
        self.meta._loaded = []
        
    def items(self):
        return self.__dict__.items()

class SubFixture(MockFixture):
    pass

class TestLoadMap(TestCase):
    
    def setUp(self):
        LoadMap.clear()
    
    def test_stickiness(self):
        
        bob = MockFixture(name="bob", dayjob="scientist")
        bob.meta.req.fred = MockFixture(name="fred")
        bob.meta.req.betty  = MockFixture(name="betty")
        
        assert not LoadMap.is_registered(bob)
        
        LoadMap.register(bob)
        
        julie = MockFixture(name="julie", dayjob="hair stylist")
        
        self.assertNotEqual(LoadMap.ID(bob), LoadMap.ID(julie))
        
        assert LoadMap.is_registered(julie)
        LoadMap.populate(julie)
        
        assert julie.name == bob.name
        assert julie.dayjob == bob.dayjob
        self.assertEqual( julie.meta.req._pool, bob.meta.req._pool)
        
        harvey = SubFixture(name='harvey', dayjob='unemployed')
        assert not LoadMap.is_registered(harvey)
    
    def test_update(self):
        bob = MockFixture(name="bob", dayjob="scientist")
        LoadMap.register(bob)
        
        bob.__dict__['hobby'] = "model airplanes"
        LoadMap.update(bob)
        
        nancy = MockFixture()
        LoadMap.populate(nancy)
        
        assert nancy.name == bob.name
        assert nancy.dayjob == bob.dayjob
        assert nancy.hobby == bob.hobby

