# -*- coding: latin_1 -*-

import os
from os.path import join, exists, isdir, basename
import testtools
from testtools.io import *
from copy import copy

french = "tu pense qu'on peut m'utiliser comme ça?"

def test_export():
    assert 'io' in testtools.__all__

def test_mkdirall():
    tmp = TempIO()
    cwd = os.getcwd()
    try:
        mkdirall(join(tmp.root, 'blah/blah/'))
        assert exists(join(tmp.root, 'blah/blah'))
        
        # relative too ...
        os.chdir(tmp.root)
        mkdirall('ici/ou/la')
        assert exists('ici')
        assert exists('ici/ou')
        assert exists('ici/ou/la')
        
    finally:
        del tmp
        os.chdir(cwd)

def test_putfile():
    tmp = TempIO()
    cwd = os.getcwd()
    try:
    
        fname = join(tmp.root, 'french.txt')
        putfile(fname, french)
    
        assert exists(fname)
    
        f = open(fname, 'r')
        contents = f.read()
        f.close()
        assert contents == french
        
        # can make lazy dirs ..
        fname = join(tmp.root, 'ou/est/tu/frenchy.txt')
        putfile(fname, "")
        assert exists(fname)
        
        # relative :
        os.chdir(tmp.root)
        putfile('bahh', '')
        assert exists(join(tmp.root, 'bahh'))
        
    finally:
        del tmp
        os.chdir(cwd)

def test_readfile():
    tmp = TempIO()
    try:
        blah_fname = join(tmp.root, 'blah.txt')
        f = open(blah_fname, 'w')
        f.write('blah blah blah')
        f.close()
    
        assert readfile(blah_fname)=="blah blah blah"
    finally:
        del tmp

def test_TempIO_deferred():
    tmp = TempIO(deferred=True)
    root = tmp.root
    assert exists(root)
    del tmp
    assert exists(root)
    
    tmp = TempIO(deferred=False)
    root = tmp.root
    assert exists(root)
    del tmp
    assert not exists(root)

def test_TempIO_del():
    tmp = TempIO()
    root = copy(tmp.root)
    del tmp
    assert not exists(root)

def test_TempIO_del_self_destruct():
    """asserts local var can self destruct without warning about an exception."""
    tmp = TempIO()

TMP = None
def test_TempIO_del_mod_level():
    '''asserts that a module level reference self destruct without exception.'''
    # this used to pass with nosetests 0.8.7.1 but now it fails again
    # with an import error on shutil.
    # hmmm.
    global TMP
    TMP = TempIO()

def test_TempIO_keywords():
    tmp = TempIO()
    try:
        tmp_custom = TempIO(prefix='foobar_', dir=tmp.root)
        try:
            assert exists(join(tmp.root, basename(tmp_custom.root)))
            assert basename(tmp_custom.root).startswith('foobar_')
        finally:
            del tmp_custom
    finally:
        del tmp

def test_TempIO_mkdir():
    tmp = TempIO()
    try:
        base1 = tmp.mkdir('base1')
        assert exists(join(tmp.root, base1))
        base2 = tmp.mkdir('base2')
        assert exists(join(tmp.root, base2))
    finally:
        del tmp

def test_TempIO_newdir():
    tmp = TempIO()
    try:
        fp = tmp.newdir('rick_james')
        assert exists(fp)
        assert exists(tmp.rick_james)
    finally:
        del tmp

def test_TempIO_mkfile():
    tmp = TempIO()
    try:
        fname = tmp.mkfile('path/to/foobar.txt')
    
        assert fname == join(tmp.root, 'path/to/foobar.txt')
        assert exists(join(tmp.root, 'path/to'))
    
        fname = tmp.mkfile('bar.txt')
        assert fname == join(tmp.root, 'bar.txt')
    finally:
        del tmp

def test_TempIO_putfile():
    tmp = TempIO()
    try:
        tmp.putfile('frenchy.txt', french)
    
        assert exists(join(tmp.root, 'frenchy.txt'))
        assert readfile(join(tmp.root, 'frenchy.txt'), pad=False) == french
    
        tmp.putfile('petite/grenouille/frenchy.txt', french)
        assert exists(join(tmp.root, 'petite/grenouille/frenchy.txt'))
    
        # check laziness of putfile's mkdir'ing :
        tmp.putfile('petite/grenouille/ribbit/frenchy.txt', french)
        assert exists(join(tmp.root, 'petite/grenouille/ribbit/frenchy.txt'))
    finally:
        del tmp

def test_TempIO_root():
    tmp = TempIO()
    try:
        assert isdir(tmp.root)
    finally:
        del tmp
    